summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--ChangeLog4
-rw-r--r--README2
-rwxr-xr-xsrc/cddb.cpp2
-rwxr-xr-xsrc/config.cpp10
4 files changed, 9 insertions, 9 deletions
diff --git a/ChangeLog b/ChangeLog
index 9279485..566f6b7 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -24,8 +24,8 @@
-Change: Use extension to determine file type if no mime type file was found
0.3.6:
--Fix: Don't crash when using kio_audiocd
--Fix: Show progress when using kio_audiocd
+-Fix: Don't crash when using tdeio_audiocd
+-Fix: Show progress when using tdeio_audiocd
-Fix: Show the soundkonverter window when started with --rip option
-Fix: Handle remote files properly (http, smb, etc.)
diff --git a/README b/README
index f043066..4727765 100644
--- a/README
+++ b/README
@@ -21,7 +21,7 @@ The key features are:
It is extendable by plugins and supports many backends:
En-/decoding: oggenc/oggdec, lame, gogo, faac/faad, mppenc/mppdec, flac, mac, mplayer, ffmpeg, shorten, ttaenc, bonk, ofr, ofs, wavpack, lac, lpac, speexenc/speexdec, timidity
Replay Gain: vorbisgain, mp3gain, aacgain, replaygain (MusePack), metaflac, wvgain
- CD ripping: kio_audiocd, cdda2wav, cdparanoia
+ CD ripping: tdeio_audiocd, cdda2wav, cdparanoia
This way you can convert between various audio formats:
Decoding: ogg, mp3, mp2, m4a/mp4, aac, 3gp, mpc/mp+, flac, ape, wma, asf/asx, ra, rv, rm, avi, mpeg, wmv, qt/mov, flv, ac3, au/snd, shn, tta, bonk, ofr, ofs, wv, la, pac, spx, mid, mod/s3m/stm/ult/uni/xm/m15/mtm/669/it, wav
Encoing: ogg, mp3, mp2, m4a, aac, mpc, flac, ape, ra, ac3, au, shn, tta, bonk, ofr, ofs, wv, la, pac, spx, wav
diff --git a/src/cddb.cpp b/src/cddb.cpp
index cbc936c..ebc2501 100755
--- a/src/cddb.cpp
+++ b/src/cddb.cpp
@@ -88,7 +88,7 @@ CDDB::set_server(const char *hostname, unsigned short int _port)
port = _port;
TQCString r;
readLine(r); // the server greeting
- writeLine("cddb hello kde-user blubb kio_audiocd 0.4");
+ writeLine("cddb hello kde-user blubb tdeio_audiocd 0.4");
readLine(r);
}
return true;
diff --git a/src/config.cpp b/src/config.cpp
index ac169aa..ea71d2f 100755
--- a/src/config.cpp
+++ b/src/config.cpp
@@ -131,11 +131,11 @@ void Config::read()
data.environment.foundPrograms = conf->readListEntry( "foundPrograms", listDefaults );
conf->setGroup( "Ripper" );
- ripper = conf->readEntry( "ripper", "kio_audiocd" );
+ ripper = conf->readEntry( "ripper", "tdeio_audiocd" );
- if( ripper == "kio_audiocd" ) rank = 10000;
- else rank = 60; // kio_audiocd ranking
- currentRipper = 0; // this is a valid ripper (kio_audiocd)
+ if( ripper == "tdeio_audiocd" ) rank = 10000;
+ else rank = 60; // tdeio_audiocd ranking
+ currentRipper = 0; // this is a valid ripper (tdeio_audiocd)
for( TQValueList<RipperPlugin*>::Iterator b = rippers.begin(); b != rippers.end(); ++b ) {
binaries[ (*b)->rip.bin ] = "";
if( (*b)->rip.rank > rank ) {
@@ -269,7 +269,7 @@ void Config::write( bool sync )
TDEConfig *conf = kapp->config();
conf->setGroup( "Ripper" );
- conf->writeEntry( "ripper", (currentRipper)?currentRipper->rip.bin:"kio_audiocd" );
+ conf->writeEntry( "ripper", (currentRipper)?currentRipper->rip.bin:"tdeio_audiocd" );
for( TQValueList<FormatItem>::Iterator it = formats.begin(); it != formats.end(); ++it )
{